@@ -1,6 +1,6 @@
 #################################################################################
 ##
-##   R package rmgarch by Alexios Ghalanos Copyright (C) 2008-2013.
+##   R package rmgarch by Alexios Galanos Copyright (C) 2008-2022.
 ##   This file is part of the R package rmgarch.
 ##
 ##   The R package rmgarch is free software: you can redistribute it and/or modify
@@ -80,21 +80,21 @@ rmgarch.test5a = function(cluster = NULL)
 			length(ffit4@mfit$matcoef[,1])) +  (3^2 - 3)/2
 	# (3^2-2)/2 is the calculated unconditional matrix
 	aicmod = c(
-			rugarch:::.information.test(fit1@mfit$llh,  nObs = fit1@model$modeldata$T, 
+			.information.test(fit1@mfit$llh,  nObs = fit1@model$modeldata$T, 
 					nPars = np[1])[[1]],
-			rugarch:::.information.test(ffit1@mfit$llh, nObs = ffit1@model$modeldata$T, 
+			.information.test(ffit1@mfit$llh, nObs = ffit1@model$modeldata$T, 
 					nPars = np[2])[[1]],
-			rugarch:::.information.test(fit2@mfit$llh,  nObs = fit2@model$modeldata$T, 
+			.information.test(fit2@mfit$llh,  nObs = fit2@model$modeldata$T, 
 					nPars = np[3])[[1]],
-			rugarch:::.information.test(ffit2@mfit$llh, nObs = ffit2@model$modeldata$T, 
+			.information.test(ffit2@mfit$llh, nObs = ffit2@model$modeldata$T, 
 					nPars = np[4])[[1]],
-			rugarch:::.information.test(fit3@mfit$llh,  nObs = fit3@model$modeldata$T, 
+			.information.test(fit3@mfit$llh,  nObs = fit3@model$modeldata$T, 
 					nPars = np[5])[[1]],
-			rugarch:::.information.test(ffit3@mfit$llh, nObs = ffit3@model$modeldata$T, 
+			.information.test(ffit3@mfit$llh, nObs = ffit3@model$modeldata$T, 
 					nPars = np[6])[[1]],
-			rugarch:::.information.test(fit4@mfit$llh,  nObs = fit4@model$modeldata$T, 
+			.information.test(fit4@mfit$llh,  nObs = fit4@model$modeldata$T, 
 					nPars = np[7])[[1]],
-			rugarch:::.information.test(ffit4@mfit$llh, nObs = ffit4@model$modeldata$T, 
+			.information.test(ffit4@mfit$llh, nObs = ffit4@model$modeldata$T, 
 					nPars = np[8])[[1]])
 	tmp = data.frame(n.pars = np, AIC = aicmod)
 	rownames(tmp) = paste("Model_", 1:8, sep = "")
@@ -570,4 +570,4 @@ rmgarch.test5d = function(cluster = NULL)
 	lines(Rx2, main = paste(cnames[1],"-",cnames[5],sep=""), col = "tomato1")
 	legend("topleft", c("FDCC", "DCC"), col = c("steelblue", "tomato1"), lty=c(1,1), bty="n")
 	dev.off()
-}
\ No newline at end of file
+}
